@@ -5,5 +5,8 @@
 #include <phat/phathfanslider.h>
 #include <phat/phatfanslider.h>
 #include <phat/phatsliderbutton.h>
+#include <phat/phatkeyboard.h>
+#include <phat/phatvkeyboard.h>
+#include <phat/phathkeyboard.h>
 
 #endif /* __PHAT_H__ */
